package es.juntadeandalucia.eni.componentes;

/**
 * @author everis
 */
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Image;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.WindowConstants;

/**
 * The Class Ventana.
 */
public class JVentana extends JFrame {
	
	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;

	/** The TAMAN o_ ventana. */
	private static Dimension TAMANO_VENTANA = new Dimension(850, 450);
	
	/** The TITULO. */
	protected static String TITULO = "Esquema Nacional de Interoperabilidad";
	
	/** The RUT a_ icono. */
	protected static String RUTA_ICONO = "/imagenes/eniFav.png";

	/** The Constant COLOR_FONDO. */
	protected static final Color COLOR_FONDO = new Color(238, 238, 238);
	
	/** The lbl imagen. */
	private JLabel lblImagen;

	/** The pnl login. */
	protected JPanel pnlImagen;

	/** The jContentPanel. */
	private JPanel jContentPanel = null;

	/**
	 * Constructor por defecto. Ajusta el tamaño de la ventana a 850x250 Titulo
	 * e icono por defecto DISPOSE_ON_CLOSE en el modo de cierre.
	 */
	public JVentana() {
		this.jContentPanel = new JPanel();
		this.jContentPanel.setLayout(new BorderLayout());
		setSize(TAMANO_VENTANA);
		setTitle(TITULO);
		setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		setLocationRelativeTo(null);
		setResizable(Boolean.FALSE);
		Image icon = new ImageIcon(getClass().getResource(RUTA_ICONO))
				.getImage();
		setIconImage(icon);
		estableceLayout("");
	}

	/**
	 * Constructor por defecto. Ajusta el tamaño de la ventana a 850x250 Titulo
	 * e icono por defecto DISPOSE_ON_CLOSE en el modo de cierre.
	 *
	 * @param cabecera the cabecera
	 */
	public JVentana(String cabecera) {
		this.jContentPanel = new JPanel();
		this.jContentPanel.setLayout(new BorderLayout());
		setSize(TAMANO_VENTANA);
		setTitle(TITULO);
		setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		setLocationRelativeTo(null);
		setResizable(Boolean.FALSE);
		Image icon = new ImageIcon(getClass().getResource(RUTA_ICONO))
				.getImage();
		setIconImage(icon);
		estableceLayout(cabecera);
	}

	/**
	 * Constructor con parámetros.
	 *
	 * @param dimensiones : Dimensiones de la ventana. Si es null toma el valor por
	 * defecto.
	 * @param titulo : Título de la ventana. Si es null toma el valor por defecto.
	 * @param modoCierre : Modo de cierre de la ventana. Si es null toma el valor por
	 * defecto.
	 * @param redimensionable : Indica si es redimensionable o no. Si es null toma el valor
	 * por defecto.
	 * @param cabecera the cabecera
	 */
	public JVentana(Dimension dimensiones, String titulo, Integer modoCierre,
			Boolean redimensionable, String cabecera) {
		this.jContentPanel = new JPanel();
		this.jContentPanel.setLayout(new BorderLayout());
		Image icon = new ImageIcon(getClass().getResource(RUTA_ICONO))
				.getImage();
		setIconImage(icon);
		setSize(dimensiones != null ? dimensiones : TAMANO_VENTANA);
		setTitle(titulo != null ? titulo : TITULO);
		setDefaultCloseOperation(modoCierre != null ? modoCierre
				: WindowConstants.DISPOSE_ON_CLOSE);
		setResizable(redimensionable != null ? redimensionable : false);
		setLocationRelativeTo(null);
		setVisible(Boolean.FALSE);
		estableceLayout(cabecera);
	}

	/**
	 * Establece layout.
	 *
	 * @param cabecera the cabecera
	 */
	private void estableceLayout(String cabecera) {
		// Imagen
		pnlImagen = new JPanel(new FlowLayout(FlowLayout.LEFT));
		Box boxImagen = Box.createHorizontalBox();
		lblImagen = new JLabel(new ImageIcon(getClass().getResource(
				"/imagenes/eni.png")));
		boxImagen.add(Box.createHorizontalStrut(15));
		boxImagen.add(lblImagen);
		boxImagen.add(Box.createHorizontalStrut(150));
		String mensaje = "Acceso a la herramienta";
		if (cabecera != null && !"".equals(cabecera)) {
			mensaje = cabecera;
		}
		JLabel lblDestino = new JLabel("<html><h2><font color='#00A8D3'>"
				+ mensaje + "</font><h2></html>");
		boxImagen.add(lblDestino);
		pnlImagen.add(boxImagen);
	}

	/**
	 * Gets the j content panel.
	 *
	 * @return the j content panel
	 */
	public JPanel getjContentPanel() {
		return jContentPanel;
	}

	/**
	 * Sets the j content panel.
	 *
	 * @param jContentPanel the new j content panel
	 */
	public void setjContentPanel(JPanel jContentPanel) {
		this.jContentPanel = jContentPanel;
	}
	
	/**
	 * Metodo cierre.
	 *
	 * @param metodoCierre the metodo cierre
	 */
	public void metodoCierre(int metodoCierre){
		setDefaultCloseOperation(metodoCierre);
	}
}